# Changelog

## 0.1.0-alpha.1 (2024-12-14)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/identety/identety-python-sdk/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** manual updates ([#5](https://github.com/identety/identety-python-sdk/issues/5)) ([27c8e66](https://github.com/identety/identety-python-sdk/commit/27c8e66ad55e6fc1103a73a0aad0bcccc83ccd86))

## 0.0.1-alpha.1 (2024-12-14)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/identety/identety-python-sdk/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([#1](https://github.com/identety/identety-python-sdk/issues/1)) ([9e57fc1](https://github.com/identety/identety-python-sdk/commit/9e57fc19c9a52d9fedeffb292b6172642c9aa7d1))
* update SDK settings ([#3](https://github.com/identety/identety-python-sdk/issues/3)) ([8a5311d](https://github.com/identety/identety-python-sdk/commit/8a5311d4ada0c9ca745fe0c208e9302cb6132fc6))
